@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: upload-item.cpp 495 2005-08-18 00:49:35Z svn $
+ * $Id: upload-item.cpp 622 2005-09-06 20:09:51Z svn $
  *****************************************************************************/
 
 #include "upload-item.h"
@@ -33,8 +33,6 @@
 #include "apr_pools.h"
 #include "apr_time.h"
 
-static const apr_time_t MICROSECOND_FACTOR = 1000000;
-
 static VALUE list_total_file_size(VALUE self);
 static VALUE reader_alloc(VALUE klass);
 static void reader_free(reader_impl *impl);
@@ -146,7 +144,7 @@ VALUE reader_read(VALUE self, VALUE file_path)
                       rb_str_new2(header->file_name),
                       rb_str_new2(header->file_mime),
                       UINT2NUM(header->file_size),
-                      UINT2NUM(header->time/MICROSECOND_FACTOR),
+                      UINT2NUM(header->time/APR_USEC_PER_SEC),
                       rb_str_new2(header->comment),
                       rb_str_new2(header->remove_pass),
                       rb_str_new2(header->download_pass));
