@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploadItemCreator.h 535 2005-08-30 20:15:17Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMCREATOR_H
@@ -67,7 +67,8 @@ private:
     UploadItemCreator(const UploadItemCreator&);
     UploadItemCreator &operator=(const UploadItemCreator&);
 
-    static void validate_query(UploadParser::query_map *qmap);
+    static void validate_query(apr_pool_t *pool, UploadParser::query_map *qmap);
+    static void convert_code(apr_pool_t *pool, string &str, const unsigned char *code_pat);
     static void set_file_data(apr_pool_t *pool, UploadItem::header *data,
                               UploadParser::file_content& file,
                               UploadParser::query_map *qmap);
