@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploadItemReader.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMREADER_H
@@ -56,7 +56,7 @@ class UploadItemReader
     UploadItemReader(const UploadItemReader&);
     UploadItemReader &operator=(const UploadItemReader&);
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     const char * const file_dir_;
 };
 
