@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.c 550 2005-09-01 07:23:16Z svn $
+ * $Id: Auxiliary.c 627 2005-09-06 22:47:19Z svn $
  *****************************************************************************/
 
 #include "Auxiliary.h"
@@ -77,10 +77,9 @@ const char *rfc1738_encode(apr_pool_t *pool, const char* str)
 
 const char *size_str(apr_pool_t *pool, apr_uint64_t size)
 {
+#ifdef NO_FLOAT
     if (size > 1024*1024*1024) {
-        return apr_psprintf(pool, "%s%s",
-                            comma_str(pool, (apr_size_t)(size/(1024*1024*1024))),
-                            GBYTE_UNIT);
+        return apr_psprintf(pool, "%" APR_UINT64_T_FMT "%s", size/(1024*1024*1024), GBYTE_UNIT);
     } else if (size > 1024*1024) {
         return apr_psprintf(pool, "%" APR_UINT64_T_FMT "%s", size/(1024*1024), MBYTE_UNIT);
     } else if (size > 1024) {
@@ -88,6 +87,17 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
     } else {
         return apr_psprintf(pool, "%" APR_UINT64_T_FMT "%s", size, BYTE_UNIT);
     }
+#else
+    if (size > 1024*1024*1024) {
+        return apr_psprintf(pool, "%.1f%s", (float)(size/(1024*1024*1024)), GBYTE_UNIT);
+    } else if (size > 1024*1024) {
+        return apr_psprintf(pool, "%.1f%s", (float)size/(1024*1024), MBYTE_UNIT);
+    } else if (size > 1024) {
+        return apr_psprintf(pool, "%.1f%s", (float)size/1024, KBYTE_UNIT);
+    } else {
+        return apr_psprintf(pool, "%.1f%s", (float)size, BYTE_UNIT);
+    }
+#endif
 }
 
 const char *comma_str(apr_pool_t *pool, apr_size_t number)
