@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 589 2005-09-05 02:01:25Z svn $
+ * $Id: UploaderConfig.cpp 593 2005-09-05 14:41:59Z svn $
  *****************************************************************************/
 
 #include "mod_uploader_data.h"
@@ -377,8 +377,7 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
 
     if (apr_file_open(&file, template_path, APR_READ,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
-        throw apr_psprintf(pool,
-                           "Can not open page template (%s).", template_path);
+        throw apr_psprintf(pool, "Can not open page template. (%s)", template_path);
     }
 
     try {
@@ -426,8 +425,7 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *path)
     time = mtime(pool, path);
 
     if (UNLIKELY(time == 0)) {
-        throw apr_psprintf(pool,
-                           "Can not get information of file/directory (%s).",
+        throw apr_psprintf(pool, "Can not get information of file/directory. (%s)",
                            path);
     }
 
