@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 589 2005-09-05 02:01:25Z svn $
+ * $Id: mod_uploader.cpp 626 2005-09-06 22:39:53Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -43,7 +43,8 @@
 #include "Misc.h"
 
 #include "http_core.h"
-#if !defined(OS2) && !defined(WIN32) && !defined(BEOS) && !defined(NETWARE)
+
+#ifdef AP_NEED_SET_MUTEX_PERMS
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -51,9 +52,7 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#define MOD_UPLOADER_SET_MUTEX_PERMS
 #endif
-
 #define APR_WANT_STRFUNC
 #include "apr_want.h"
 
@@ -120,7 +119,7 @@ int command_handler(request_rec *r, uconfig *config, const char *arg)
 {
     const char *command;
 
-    if (*arg == '\0') {
+    if (UNLIKELY(*arg == '\0')) {
         apr_table_set(r->headers_out, "Location", apr_pstrcat(r->pool, r->uri, "/", NULL));
 
         return HTTP_TEMPORARY_REDIRECT;
@@ -129,7 +128,7 @@ int command_handler(request_rec *r, uconfig *config, const char *arg)
 
     command = ap_getword(r->pool, &arg, '/');
 
-    if (*command == '\0') {
+    if (LIKELY(*command == '\0')) {
         return view(r, config, arg);
     } else if (strcmp(command, RSS_COMMAND) == 0) {
         return rss(r, config, arg);
@@ -318,14 +317,14 @@ int upload(request_rec *r, uconfig *config, const char *arg)
         config->gwrite_lock();
         try {
             config->item_list->add(file_name, true);
+            add_poster_list(r, address);
+
             config->gwrite_unlock();
         } catch(const char *) {
             config->gwrite_unlock();
             throw;
         }
 
-        add_poster_list(r, address);
-
         return redirect_top(r);
     } catch(const char *message) {
         return error(r, config, message);
@@ -494,7 +493,8 @@ int error(request_rec *r, uconfig *config, const char *error)
 
 int redirect_top(request_rec *r)
 {
-    // 쥯ȤϻȤʤ
+    // POST ˥ڡñ˥ɤǤ褦ˤ뤿ᡤHTML 
+    // 쥯Ȥ롥
 
     ap_set_content_type(r, "text/html");
 
@@ -504,7 +504,7 @@ int redirect_top(request_rec *r)
     ap_rputs(" <head>", r);
     ap_rputs("  <meta http-equiv=\"content-type\" content=\"application/xhtml+xml\" />", r);
     ap_rputs("  <meta http-equiv=\"refresh\" content=\"0;url=../\" />", r);
-    ap_rputs("  <title>" PACKAGE_NAME "</title>", r);
+    ap_rputs("  <title>mod_uploader</title>", r);
     ap_rputs(" </head>", r);
     ap_rputs(" <body />", r);
     ap_rputs("</html>", r);
@@ -754,6 +754,7 @@ void add_poster_list(request_rec *r, const char *address)
         config->poster_list[i].time = 0;
     }
 
+    // ɬ׺¤ϰϤȤʤ
     qsort(config->poster_list, j + 1, sizeof(poster),
           reinterpret_cast<int(*)(const void *, const void *)>(poster_compare));
 }
@@ -875,7 +876,7 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
         return HTTP_INTERNAL_SERVER_ERROR;
     }
 
-#ifdef MOD_UPLOADER_SET_MUTEX_PERMS
+#ifdef AP_NEED_SET_MUTEX_PERMS
     status = unixd_set_global_mutex_perms(config->glock);
     if (status != APR_SUCCESS) {
         SERROR("Can not set permissions on global mutex (%s).", config->poster_list_path);
@@ -884,7 +885,6 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
         return HTTP_INTERNAL_SERVER_ERROR;
     }
 #endif
-    apr_pool_cleanup_register(pconf, config, finalize_server_config, apr_pool_cleanup_null);
 
     // ޤϡAnonymous Shared Memory Ƥߤ롥
     status = apr_shm_create(&(config->poster_list_shm), sizeof(poster)*POSTER_HISTORY_NUMBER,
@@ -908,6 +908,8 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
     ap_add_version_component(pconf, PACKAGE_NAME "/" PACKAGE_VERSION);
 #endif
 
+    apr_pool_cleanup_register(pconf, config, finalize_server_config, apr_pool_cleanup_null);
+
     return OK;
 }
 
